import React, { useState } from 'react';
import ReactDOM from 'react-dom';

function LocationForm(props) {
  return (
    <form onSubmit={props.handleSubmit}>
            <label>Name: </label>
            <input 
             type="text" 
             name="name" 
              />
             <br />

            <label>State</label>
            <select name="state">
                <option value="CA">CA</option>
                <option value="NY">NY</option>
                <option value="TX">TX</option>
            </select><br />

            <input type="submit" value="Save Location" />

        </form>
  );
}

function LocationDisplay(props) {
  /*
  Note on locationList: I ended up taking Ryan's original advice and use
  the map function that is available for all arrays. props.data.map(function) enables
  you to create a new list where you execute the passed in function for every element in 
  data.map.

  Check https://medium.com/@bojangbusiness/javascript-functional-programming-map-filter-and-reduce-846ff9ba492d
  for details
  
  */
  const locationList = props.data.map(
    (location, index) => (<li key={index}>{location.name}: {location.state}</li>));

  return (
    <ul>
      {locationList} 
    </ul>
  );
}

function LocationComponent(props) {

  const [data, setData] = useState(getLocalStorageData(props.id));
  const handleSubmit = (event) =>  {
  	 event.preventDefault();

    /* After the class I simplified this to use a single statement to add the
    current data and add the new data at the end of it 
    */
  	 const newData = [
       ...data, {
       "name": event.target.name.value,
       "state": event.target.state.value
      }];

      setData(newData);
      setLocalStorageData(props.id, newData)
   }

   function getLocalStorageData(id) {
     /* Note that I now have these seperate functions getLocalStorageData and
     setLocalStorageData separated out as their own function. I do this to 
     encapsulate the retrieval and saving of data to local storate.
     Hint: doing this makes it easy to switch data providers from local storage to
     lets say an external database.
     */
    const localStorageData = localStorage.getItem(`LocationComponentData${id}`)
    
    /* Note that I use JSON.parse here. localStorage can save only strings. So you need
    the ability to "serialize" an array into text, and to deserialize text back into an
    array. JSON.parse converts a JSON string into an object (in this case an array) and
    JSON.stringify converts an object (in this case an array) into a JSON string */

    if (localStorageData == null) {
      return JSON.parse("[]");
    }

    return JSON.parse(localStorageData);
  }
  
  function setLocalStorageData(id, curData) {
    /* Note that I now have these seperate functions getLocalStorageData and
     setLocalStorageData separated out as their own function. I do this to 
     encapsulate the retrieval and saving of data to local storate.
     Hint: doing this makes it easy to switch data providers from local storage to
     lets say an external database.
     */
    const thisData = curData;

    /* Note that I use JSON.parse here. localStorage can save only strings. So you need
    the ability to "serialize" an array into text, and to deserialize text back into an
    array. JSON.parse converts a JSON string into an object (in this case an array) and
    JSON.stringify converts an object (in this case an array) into a JSON string */
    localStorage.setItem(`LocationComponentData${id}`, JSON.stringify(thisData));
  }
   return (
    <div>
      <LocationForm handleSubmit={handleSubmit} />
      <br />
      <LocationDisplay data={data} />
    </div>
  );
}

function App(props) {
  return (
    <div>
      <LocationComponent id="1" />
    </div>
  );
}

ReactDOM.render(
<App />,
document.getElementById('root')
);


 